"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var SelectComponent = (function () {
    function SelectComponent() {
        this.changeValueEvent = new core_1.EventEmitter();
        this.showThis = false;
        this.isFocus = false;
    }
    SelectComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (this.currentSelect && this.optionList) {
            var result = this.optionList.find(function (item) { return _this.currentSelect === item; });
            this.currentValue = result && (result[this.displayField] || result);
        }
    };
    SelectComponent.prototype.changeCurrentValue = function () {
        var _this = this;
        var result = this.optionList.find(function (item) { return _this.currentSelect === item; });
        this.currentValue = result && (result[this.displayField] || result);
    };
    SelectComponent.prototype.onDocumentClick = function (event) {
        if (!this.disable) {
            if (event.target !== this.inputSelect.nativeElement &&
                event.target !== this.dropBtn.nativeElement &&
                event.target.parentNode !== this.dropBtn.nativeElement) {
                this.dropList.nativeElement.style.display = 'none';
                this.isFocus = false;
                if (this.keyword) {
                    this.currentValue = this.keyword;
                    this.keyword = '';
                }
            }
            else {
                var elm = this.dropList.nativeElement;
                if (event.target === this.dropBtn.nativeElement ||
                    event.target.parentNode === this.dropBtn.nativeElement) {
                    elm.style.display = elm.style.display === 'block' ? 'none' : 'block';
                    this.isFocus = !this.isFocus;
                }
                else {
                    elm.style.display = 'block';
                    this.isFocus = true;
                }
            }
        }
    };
    SelectComponent.prototype.filter = function (data, keyword) {
        var _this = this;
        if (!this.isReadonly && keyword) {
            return data.filter(function (item) { return item[_this.displayField].indexOf(keyword) > -1; });
        }
        else {
            return data || [];
        }
    };
    SelectComponent.prototype.confirm = function () {
        var _this = this;
        var result = this.optionList.filter(function (item) { return item[_this.displayField].indexOf(_this.keyword) > -1; });
        if (result && result.length === 1) {
            this.dropList.nativeElement.style.display = 'none';
            this.inputSelect.nativeElement.blur();
            this.currentValue = result[0][this.displayField] || result[0];
            this.keyword = '';
            this.isFocus = false;
        }
    };
    SelectComponent.prototype.changeValue = function (option) {
        var value = option[this.outputField] || option;
        this.currentValue = option[this.displayField] || option;
        this.keyword = '';
        this.changeValueEvent.emit(value);
    };
    SelectComponent.prototype.trackByIndex = function (index, value) {
        return index;
    };
    SelectComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: 'dc-select',
                    template: "<div class=\"dc-select-container\" [ngClass]=\"{'disable':disable}\" [style.width]=\"width\">\n  <div class=\"dc-select-input\">\n    <input name=\"dcSelect\" [(ngModel)]=\"keyword\" [disabled]=\"disable\" [readonly]=\"isReadonly\" (keyup.enter)=\"confirm()\" #inputSelect>\n    <span [hidden]=\"(keyword && keyword.length>0) || isFocus\">{{currentValue}}</span>\n    <div class=\"dc-select-btn\" #dropBtn>\n      <div class=\"dc-select-arrow\"></div>\n    </div>\n  </div>\n  <ul class=\"dc-select-drop\" #dropList [style.maxHeight]=\"maxHeight\">\n    <li *ngFor=\"let option of filter(optionList, keyword); let i = index; trackBy: trackByIndex \" (click)=\"changeValue(option)\" [class.selected]=\"currentValue==option[displayField]\">{{option[displayField] || option}}</li>\n  </ul>\n</div>",
                    styles: [
                        ".dc-select-container {\n      width: 160px;\n      height: 30px;\n      font-size: 12px;\n      color: #333;\n      background: #fff;\n      border: solid 1px #ccc;\n      border-radius: 3px;\n      margin: 0 10px;\n      padding: 0;\n      display: inline-block;\n      position: relative\n  }\n  \n  .dc-select-container:hover {\n      border-color: #3d70b2\n  }\n  \n  .dc-select-container:active {\n      border-color: #0081cc\n  }\n  \n  .dc-select-container.disable {\n      background: #f5f5f5;\n      border-color: #ccc;\n      color: #999\n  }\n  \n  .dc-select-input {\n      padding: 5px 10px;\n      width: 100%;\n      height: 30px;\n      position: relative;\n  }\n  \n  .dc-select-input>input {\n      outline: none;\n      border: none;\n      width: 90%;\n      height: 18px;\n      line-height: 18px;\n      background: none;\n      position: relative;\n      z-index: 1;\n  }\n  \n  .dc-select-input>input:read-only {\n      cursor: default\n  }\n  \n  .dc-select-input>span {\n      display: block;\n      position: absolute;\n      width: 78%;\n      height: 18px;\n      left: 10px;\n      top: 5px;\n      line-height: 18px;\n      overflow: hidden;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      z-index: 0;\n  }\n  \n  .dc-select-btn {\n      width: 0;\n      height: 30px;\n      position: absolute;\n      right: 0;\n      top: 0;\n      padding: 12px 20px 0 10px;\n      cursor: pointer;\n  }\n  \n  .dc-select-container.disable .dc-select-btn {\n      cursor: default;\n  }\n  \n  .dc-select-arrow {\n      border: solid 4px transparent;\n      border-top-width: 6px;\n      border-top-color: #333;\n      width: 0;\n      height: 0;\n  }\n  \n  .dc-select-container.disable .dc-select-arrow {\n      border-top-color: #ccc;\n  }\n  \n  .dc-select-drop {\n      position: absolute;\n      top: 28px;\n      left: -1px;\n      width: calc(100% + 2px);\n      box-shadow: 0px 0px 10px 2px rgba(0, 0, 0, .2);\n      padding: 10px 0;\n      background: #fff;\n      list-style: none;\n      border-radius: 3px;\n      overflow-y: auto;\n      overflow-x: hidden;\n      display: none;\n      z-index: 1000;\n  }\n  \n  .selected{\n    background-color: #0081cc;\n    color: #ffffff;\n  }\n  \n  .dc-select-drop>li {\n      width: 100%;\n      height: 30px;\n      line-height: 26px;\n      cursor: pointer;\n      overflow: hidden;\n      text-overflow: ellipsis;\n      white-space: nowrap;\n      padding: 0 11px\n  }\n  \n  .dc-select-drop>li:hover {\n      color: #333333;\n      background: #edf0f5;\n  }"
                    ]
                },] },
    ];
    /** @nocollapse */
    SelectComponent.ctorParameters = function () { return []; };
    SelectComponent.propDecorators = {
        "optionList": [{ type: core_1.Input },],
        "currentSelect": [{ type: core_1.Input },],
        "disable": [{ type: core_1.Input },],
        "isReadonly": [{ type: core_1.Input },],
        "displayField": [{ type: core_1.Input },],
        "outputField": [{ type: core_1.Input },],
        "width": [{ type: core_1.Input },],
        "maxHeight": [{ type: core_1.Input },],
        "changeValueEvent": [{ type: core_1.Output },],
        "inputSelect": [{ type: core_1.ViewChild, args: ['inputSelect',] },],
        "dropBtn": [{ type: core_1.ViewChild, args: ['dropBtn',] },],
        "dropList": [{ type: core_1.ViewChild, args: ['dropList',] },],
        "onDocumentClick": [{ type: core_1.HostListener, args: ['document:click', ['$event'],] },],
    };
    return SelectComponent;
}());
exports.SelectComponent = SelectComponent;
//# sourceMappingURL=select.component.js.map